pygeodesy.rhumb.ekx.Rhumb

Package pygeodesy :: Package rhumb :: Module ekx :: Class Rhumb |
[frames] | no frames]

# Class Rhumb

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
             bases.RhumbBase --+
                               |
                              Rhumb

Class to solve the direct and inverse rhumb problems, based on elliptic functions or Krüger series expansion

See Also: The Detailed Description of Karney's C++ `Rhumb Class`.

Instance Methods
__init__(self, a_earth=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, f=None, exact=True, **RA_TMorder_name) New `Rhumb`. |
Direct7(self, lat1, lon1, azi12, s12, outmask=16792) DEPRECATED, use method Rhumb.Direct8. |
Inverse7(self, lat1, lon1, azi12, s12, outmask=17937) DEPRECATED, use method Rhumb.Inverse8. |
orders(self, RAorder=6, TMorder=6) DEPRECATED, use properties `RAorder` and/or `TMorder`. |
Inherited from `bases.RhumbBase`: `ArcDirect`, `Direct`, `Direct8`, `DirectLine`, `Inverse`, `Inverse8`, `InverseLine`, `Line`, `toStr` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
| RAorder Get the Rhumb Area order (`int`, 4, 5, 6, 7 or 8).
Inherited from `bases.RhumbBase`: `TMorder`, `a`, `b`, `datum`, `ellipsoid`, `equatoradius`, `exact`, `f`, `f_max`, `flattening`, `polaradius` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_earth=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, f=None, exact=True, **RA_TMorder_name) (Constructor) |
New `Rhumb`. Arguments: `a_earth` - This rhumb's earth model (Datum, Ellipsoid, Ellipsoid2, a_f2Tuple, 2-tuple `(a, f)`) or the (equatorial) radius (`meter`, conventionally). `f` - The ellipsoid's flattening (`scalar`), required if `a_earth` is `scalar`, ignored otherwise. `exact` - If `True`, use an addition theorem for elliptic integrals to compute Divided differences, otherwise use the Krüger series expansion (`bool` or `None`), see also properties `exact` and `TMorder`. `RA_TMorder_name` - Optional `name=NN` (`str`) and optional keyword arguments `RAorder`=6 and `TMorder`=6 to set the respective `order`, see properties `RAorder` and `TMorder`. Raises: `RhumbError` - Invalid `a_earth`, `f`, `RAorder` or `TMorder`. Overrides: object.__init__

### Direct7 (self, lat1, lon1, azi12, s12, outmask=16792) |
DEPRECATED, use method Rhumb.Direct8. Returns: A DEPRECATED Rhumb7Tuple. Decorators: `@deprecated_method`

### Inverse7 (self, lat1, lon1, azi12, s12, outmask=17937) |
DEPRECATED, use method Rhumb.Inverse8. Returns: A DEPRECATED Rhumb7Tuple. Decorators: `@deprecated_method`

### orders (self, RAorder=6, TMorder=6) |
DEPRECATED, use properties `RAorder` and/or `TMorder`. Get and set the RAorder and/or TMorder. Arguments: `RAorder` - Rhumb Area order (`int`, 4, 5, 6, 7 or 8). `TMorder` - Transverse Mercator order (`int`, 4, 5, 6, 7 or 8). Returns: DEPRECATED RhumbOrder2Tuple`(RAorder, TMorder)` with the previous `RAorder` and `TMorder` setting. Decorators: `@deprecated_method`

Property Details

### RAorder Get the Rhumb Area order (`int`, 4, 5, 6, 7 or 8). Get method: RAorder(self) - Get the Rhumb Area order (`int`, 4, 5, 6, 7 or 8). Set method: RAorder(self, order) - Set the Rhumb Area order (`int`, 4, 5, 6, 7 or 8). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.